// No copyright, no warranty; use as you will.
// Written by Ronald Bourret, Technical University of Darmstadt, 1998-9

// Version 1.01
// Changes from version 1.0: None

package de.tudarmstadt.ito.xmldbms;

/**
 * Interface for a class that generates key values (object IDs).
 *
 * <P>Applications that want DOMToDBMS to generate key values pass an
 * instance of an object that implements this class to DOMToDBMS. Keys
 * are used to join tables (class table-to-class table or class table-
 * to-property table) and also to retrieve data from root tables.
 * Whether DOMToDBMS generates a key for a given table (or one or more
 * properties are mapped to the key columns) depends on the mapping to
 * that table.</P>
 *
 * <P>Programmers using XML-DBMS never need to call the method (generateKey)
 * in this interface; it is called only by DOMToDBMS. Programmers only
 * need to supply an object that implements this interface to DOMToDBMS if
 * they want DOMToDBMS to generate keys.</P>
 *
 * <P>The helper class KeyGeneratorImpl provides a default implementation
 * of this interface.</P>
 *
 * @author Ronald Bourret, Technical University of Darmstadt
 * @version 1.01
 * @see de.tudarmstadt.ito.xmldbms.helpers.KeyGeneratorImpl
 */

public interface KeyGenerator
{
   /**
    * Generates a key.
    *
    * <P>This method is called by DOMToDBMS. Programmers using DOMToDBMS
    * do not need to call this method.</P>
    * 
    * @return The key as an array of Objects.
    * @exception KeyException An error occured while generating the key.
    */
   public Object[] generateKey() throws KeyException;
}

